joop.flask.example — joop 0.0.1 documentation

# Source code for joop.flask.example

    """

    This is the default place to turn example or other View definitions into
        flask-specific views.
    """

    from joop.web.examples.view import (
        NameView, HelloView
    )

    from joop.web.examples.table import MyTableWholePage

    from joop.flask.flask_view import FlaskView

    class FlaskHello(HelloView, FlaskView): pass

    class FlaskName(NameView, FlaskView): pass

    class FlaskTablePage(MyTableWholePage, FlaskView): pass